==> api-8.5.0-sources.jar: org/jrebirth/af/api/module/RegistrationPoint.java <==
/**
 * Get more info at : www.jrebirth.org .
 * Copyright JRebirth.org © 2011-2016
 * Contact : sebastien.bordes@jrebirth.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jrebirth.af.api.module;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import org.jrebirth.af.api.component.basic.Component;
import org.jrebirth.af.api.component.factory.ComponentFactory;

/**
 * The Interface RegistrationPoint is used to declare that this type can be extended.
 *
 * Implementations of this interface shall be declared using {@link Register} annotation.
 *
 * Commonly this an interface extending {@link Component} and defining a contract.
 *
 * At runtime implementation(s) will be retrieved according to {@link ComponentFactory} settings.
 */
@Target(ElementType.TYPE)
@Retention(RetentionPolicy.SOURCE)
@Documented
public @interface RegistrationPoint {

    /**
     * Exclusive.
     *
     * @return true, if successful
     */
    boolean exclusive() default true;
}

==> api-8.6.0-sources.jar: org/jrebirth/af/api/module/RegistrationPoint.java <==
/**
 * Get more info at : www.jrebirth.org .
 * Copyright JRebirth.org © 2011-2016
 * Contact : sebastien.bordes@jrebirth.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jrebirth.af.api.module;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import org.jrebirth.af.api.component.basic.Component;
import org.jrebirth.af.api.component.factory.ComponentFactory;

/**
 * The Interface RegistrationPoint is used to declare that this type can be extended.
 *
 * Implementations of this interface shall be declared using {@link Register} annotation.
 *
 * Commonly this an interface extending {@link Component} and defining a contract.
 *
 * At runtime implementation(s) will be retrieved according to {@link ComponentFactory} settings.
 */
@Target(ElementType.TYPE)
@Retention(RetentionPolicy.SOURCE)
@Documented
public @interface RegistrationPoint {

    /**
     * Exclusive flag.
     *
     * @return true, when only one component shall be built
     */
    boolean exclusive() default true;

    /**
     * Reverse flag.
     *
     * @return true, when lower priority are retrieved first
     */
    boolean reverse() default false;
}
